==> aTunes_1.9.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/modules/updates/ApplicationVersion.java <==
/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.modules.updates;

import java.beans.ConstructorProperties;

import net.sourceforge.atunes.utils.StringUtils;

/**
 * This class represents a version, i.e. "1.7.4" where 1 is major number, 7 is
 * minor number, and 4 is revision number.
 * 
 * Also contains a download URL for the version and a release date
 */
public class ApplicationVersion implements Comparable<ApplicationVersion> {

	/** Release date of version. */
	private String date;

	/** Major number. */
	private int majorNumber;

	/** Minor number. */
	private int minorNumber;

	/** Revision number. */
	private int revisionNumber;

	/** Final version? */
	private boolean finalVersion = true;

	/** Url where download this version. */
	private String downloadURL;

	ApplicationVersion() {
		super();
	}

	@ConstructorProperties( { "date", "majorNumber", "minorNumber", "revisionNumber", "finalVersion", "downloadURL" })
	public ApplicationVersion(String date, int majorNumber, int minorNumber, int revisionNumber, boolean finalVersion, String downloadURL) {
		super();
		this.date = date;
		this.majorNumber = majorNumber;
		this.minorNumber = minorNumber;
		this.revisionNumber = revisionNumber;
		this.finalVersion = finalVersion;
		this.downloadURL = downloadURL;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj instanceof ApplicationVersion) {
			return compareTo((ApplicationVersion) obj) == 0;
		}
		return false;
	}

	@SuppressWarnings("boxing")
	@Override
	public int hashCode() {
		return StringUtils.getString(majorNumber, ".", minorNumber, ".", revisionNumber, ".", finalVersion).hashCode();
	}

	/**
	 * Gets release date.
	 * 
	 * @return the date
	 */
	public String getDate() {
		return date;
	}

	/**
	 * Gets download url.
	 * 
	 * @return the download url
	 */
	public String getDownloadURL() {
		return downloadURL;
	}

	/**
	 * Gets major number.
	 * 
	 * @return the major number
	 */
	public int getMajorNumber() {
		return majorNumber;
	}

	/**
	 * Gets minor number.
	 * 
	 * @return the minor number
	 */
	public int getMinorNumber() {
		return minorNumber;
	}

	/**
	 * Gets revision number.
	 * 
	 * @return the revision number
	 */
	public int getRevisionNumber() {
		return revisionNumber;
	}

	/**
	 * Returns full version in string format.
	 * 
	 * @return the version number
	 */
	@SuppressWarnings("boxing")
	@Override
	public String toString() {
		return StringUtils.getString(majorNumber, ".", minorNumber, ".", revisionNumber, finalVersion ? " Mistral" : " (UNSTABLE BUILD)");
	}

	/**
	 * Checks if this version is not a unstable build.
	 * 
	 * @return if it's a final version
	 */
	public boolean isFinalVersion() {
		return finalVersion;
	}

	/**
	 * Sets release date.
	 * 
	 * @param date
	 *            the date
	 */
	protected void setDate(String date) {
		this.date = date;
	}

	/**
	 * Sets download url.
	 * 
	 * @param downloadURL
	 *            the download url
	 */
	protected void setDownloadURL(String downloadURL) {
		this.downloadURL = downloadURL;
	}

	/**
	 * Sets major number.
	 * 
	 * @param majorNumber
	 *            the major number
	 */
	protected void setMajorNumber(int majorNumber) {
		this.majorNumber = majorNumber;
	}

	/**
	 * Sets minor number.
	 * 
	 * @param minorNumber
	 *            the minor number
	 */
	protected void setMinorNumber(int minorNumber) {
		this.minorNumber = minorNumber;
	}

	/**
	 * Sets revision number.
	 * 
	 * @param revisionNumber
	 *            the revision number
	 */
	protected void setRevisionNumber(int revisionNumber) {
		this.revisionNumber = revisionNumber;
	}

	/**
	 * Sets the final version value
	 * 
	 * @param finalVersion
	 *            true, if this version is final
	 */
	protected void setFinalVersion(boolean finalVersion) {
		this.finalVersion = finalVersion;
	}

	@Override
	public int compareTo(ApplicationVersion version) {
		if (version == null) {
			throw new IllegalArgumentException();
		}

		if (majorNumber > version.getMajorNumber())
			return 1;
		else if (majorNumber < version.getMajorNumber())
			return -1;
		else if (minorNumber > version.getMinorNumber())
			return 1;
		else if (minorNumber < version.getMinorNumber())
			return -1;
		else if (revisionNumber > version.getRevisionNumber())
			return 1;
		else if (revisionNumber < version.getRevisionNumber())
			return -1;
		else if (finalVersion && !version.isFinalVersion())
			return 1;
		else if (!finalVersion && version.isFinalVersion())
			return -1;
		else
			return 0;
	}

}

==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/modules/updates/ApplicationVersion.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.modules.updates;

import java.beans.ConstructorProperties;

import net.sourceforge.atunes.utils.StringUtils;

/**
 * This class represents a version, i.e. "1.7.4" where 1 is major number, 7 is
 * minor number, and 4 is revision number.
 * 
 * Also contains a download URL for the version and a release date
 */
public class ApplicationVersion implements Comparable<ApplicationVersion> {

	public enum VersionType {
		BETA, RC, FINAL
	}

	/** Release date of version. */
	private String date;

	/** Major number. */
	private int majorNumber;

	/** Minor number. */
	private int minorNumber;

	/** Revision number. */
	private int revisionNumber;

	/** Final version? */
	private VersionType version = VersionType.FINAL;

	/** Name */
	private String name;

	/** Url where download this version. */
	private String downloadURL;

	ApplicationVersion() {
		super();
	}

	@ConstructorProperties( { "date", "majorNumber", "minorNumber", "revisionNumber", "version", "name", "downloadURL" })
	public ApplicationVersion(String date, int majorNumber, int minorNumber, int revisionNumber, VersionType version, String name, String downloadURL) {
		super();
		this.date = date;
		this.majorNumber = majorNumber;
		this.minorNumber = minorNumber;
		this.revisionNumber = revisionNumber;
		this.version = version;
		this.name = name;
		this.downloadURL = downloadURL;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj instanceof ApplicationVersion) {
			return compareTo((ApplicationVersion) obj) == 0;
		}
		return false;
	}

	@Override
	public int hashCode() {
		return StringUtils.getString(majorNumber, ".", minorNumber, ".", revisionNumber, ".", version).hashCode();
	}

	/**
	 * Gets release date.
	 * 
	 * @return the date
	 */
	public String getDate() {
		return date;
	}

	/**
	 * Gets download url.
	 * 
	 * @return the download url
	 */
	public String getDownloadURL() {
		return downloadURL;
	}

	/**
	 * @return the name
	 */
	public String getName() {
		return name;
	}

	/**
	 * Gets major number.
	 * 
	 * @return the major number
	 */
	public int getMajorNumber() {
		return majorNumber;
	}

	/**
	 * Gets minor number.
	 * 
	 * @return the minor number
	 */
	public int getMinorNumber() {
		return minorNumber;
	}

	/**
	 * Gets revision number.
	 * 
	 * @return the revision number
	 */
	public int getRevisionNumber() {
		return revisionNumber;
	}

	/**
	 * Returns full version in string format.
	 * 
	 * @return the version in string format
	 */
	@Override
	public String toString() {
		return StringUtils.getString(majorNumber, ".", minorNumber, ".", revisionNumber, " ", name, " ", version != VersionType.FINAL ? version : "");
	}

	/**
	 * Returns short version in string format.
	 * 
	 * @return the short version in string format
	 */
	public String toShortString() {
		return StringUtils.getString(majorNumber, ".", minorNumber, ".", revisionNumber, " ", version != VersionType.FINAL ? version : "");
	}

	/**
	 * Returns version type
	 * 
	 * @return VersionType
	 */
	public VersionType getVersion() {
		return version;
	}

	/**
	 * Sets release date.
	 * 
	 * @param date
	 *            the date
	 */
	protected void setDate(String date) {
		this.date = date;
	}

	/**
	 * @param name
	 *            the name to set
	 */
	protected void setName(String name) {
		this.name = name;
	}

	/**
	 * Sets download url.
	 * 
	 * @param downloadURL
	 *            the download url
	 */
	protected void setDownloadURL(String downloadURL) {
		this.downloadURL = downloadURL;
	}

	/**
	 * Sets major number.
	 * 
	 * @param majorNumber
	 *            the major number
	 */
	protected void setMajorNumber(int majorNumber) {
		this.majorNumber = majorNumber;
	}

	/**
	 * Sets minor number.
	 * 
	 * @param minorNumber
	 *            the minor number
	 */
	protected void setMinorNumber(int minorNumber) {
		this.minorNumber = minorNumber;
	}

	/**
	 * Sets revision number.
	 * 
	 * @param revisionNumber
	 *            the revision number
	 */
	protected void setRevisionNumber(int revisionNumber) {
		this.revisionNumber = revisionNumber;
	}

	/**
	 * Sets the version type value
	 * 
	 * @param finalVersion
	 * 
	 */
	protected void setVersion(VersionType version) {
		this.version = version;
	}

	@Override
	public int compareTo(ApplicationVersion version) {
		if (version == null) {
			throw new IllegalArgumentException();
		}

		if (majorNumber > version.getMajorNumber()) {
			return 1;
		} else if (majorNumber < version.getMajorNumber()) {
			return -1;
		} else if (minorNumber > version.getMinorNumber()) {
			return 1;
		} else if (minorNumber < version.getMinorNumber()) {
			return -1;
		} else if (revisionNumber > version.getRevisionNumber()) {
			return 1;
		} else if (revisionNumber < version.getRevisionNumber()) {
			return -1;
		} else {
			return this.version.compareTo(version.getVersion());
		}
	}

}
